@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2014 Open Source Robotics Foundation
+ * Copyright (C) 2012 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@
 #include <cmath>
 #include <ignition/math/Box.hh>
 
-#include "ignition/math/BoxPrivate.hh"
+#include "BoxPrivate.hh"
 
 using namespace ignition;
 using namespace math;
@@ -33,7 +33,6 @@ Box::Box(double _vec1X, double _vec1Y, double _vec1Z,
          double _vec2X, double _vec2Y, double _vec2Z)
 : dataPtr(new BoxPrivate)
 {
-  this->dataPtr->extent = BoxPrivate::EXTENT_FINITE;
   this->dataPtr->min.Set(_vec1X, _vec1Y, _vec1Z);
   this->dataPtr->max.Set(_vec2X, _vec2Y, _vec2Z);
 
@@ -45,7 +44,6 @@ Box::Box(double _vec1X, double _vec1Y, double _vec1Z,
 Box::Box(const Vector3d &_vec1, const Vector3d &_vec2)
 : dataPtr(new BoxPrivate)
 {
-  this->dataPtr->extent = BoxPrivate::EXTENT_FINITE;
   this->dataPtr->min = _vec1;
   this->dataPtr->min.Min(_vec2);
 
@@ -59,7 +57,6 @@ Box::Box(const Box &_b)
 {
   this->dataPtr->min = _b.dataPtr->min;
   this->dataPtr->max = _b.dataPtr->max;
-  this->dataPtr->extent = _b.dataPtr->extent;
 }
 
 //////////////////////////////////////////////////
@@ -72,19 +69,19 @@ Box::~Box()
 //////////////////////////////////////////////////
 double Box::XLength() const
 {
-  return std::abs(this->dataPtr->max.X() - this->dataPtr->min.X());
+  return std::max(0.0, this->dataPtr->max.X() - this->dataPtr->min.X());
 }
 
 //////////////////////////////////////////////////
 double Box::YLength() const
 {
-  return std::abs(this->dataPtr->max.Y() - this->dataPtr->min.Y());
+  return std::max(0.0, this->dataPtr->max.Y() - this->dataPtr->min.Y());
 }
 
 //////////////////////////////////////////////////
 double Box::ZLength() const
 {
-  return std::abs(this->dataPtr->max.Z() - this->dataPtr->min.Z());
+  return std::max(0.0, this->dataPtr->max.Z() - this->dataPtr->min.Z());
 }
 
 //////////////////////////////////////////////////
@@ -98,24 +95,15 @@ math::Vector3d Box::Size() const
 //////////////////////////////////////////////////
 math::Vector3d Box::Center() const
 {
-  return this->dataPtr->min + (this->dataPtr->max - this->dataPtr->min) * 0.5;
+  return 0.5 * this->dataPtr->min + 0.5 * this->dataPtr->max;
 }
 
 
 //////////////////////////////////////////////////
 void Box::Merge(const Box &_box)
 {
-  if (this->dataPtr->extent == BoxPrivate::EXTENT_NULL)
-  {
-    this->dataPtr->min = _box.dataPtr->min;
-    this->dataPtr->max = _box.dataPtr->max;
-    this->dataPtr->extent = _box.dataPtr->extent;
-  }
-  else
-  {
-    this->dataPtr->min.Min(_box.dataPtr->min);
-    this->dataPtr->max.Max(_box.dataPtr->max);
-  }
+  this->dataPtr->min.Min(_box.dataPtr->min);
+  this->dataPtr->max.Max(_box.dataPtr->max);
 }
 
 //////////////////////////////////////////////////
@@ -123,7 +111,6 @@ Box &Box::operator =(const Box &_b)
 {
   this->dataPtr->max = _b.dataPtr->max;
   this->dataPtr->min = _b.dataPtr->min;
-  this->dataPtr->extent = _b.dataPtr->extent;
 
   return *this;
 }
@@ -131,39 +118,16 @@ Box &Box::operator =(const Box &_b)
 //////////////////////////////////////////////////
 Box Box::operator+(const Box &_b) const
 {
-  Vector3d mn, mx;
-
-  if (this->dataPtr->extent != BoxPrivate::EXTENT_NULL)
-  {
-    mn = this->dataPtr->min;
-    mx = this->dataPtr->max;
-
-    mn.Min(_b.dataPtr->min);
-    mx.Max(_b.dataPtr->max);
-  }
-  else
-  {
-    mn = _b.dataPtr->min;
-    mx = _b.dataPtr->max;
-  }
-
-  return Box(mn, mx);
+  Box result(*this);
+  result += _b;
+  return result;
 }
 
 //////////////////////////////////////////////////
 const Box &Box::operator+=(const Box &_b)
 {
-  if (this->dataPtr->extent != BoxPrivate::EXTENT_NULL)
-  {
-    this->dataPtr->min.Min(_b.dataPtr->min);
-    this->dataPtr->max.Max(_b.dataPtr->max);
-  }
-  else
-  {
-    this->dataPtr->min = _b.dataPtr->min;
-    this->dataPtr->max = _b.dataPtr->max;
-    this->dataPtr->extent = _b.dataPtr->extent;
-  }
+  this->dataPtr->min.Min(_b.dataPtr->min);
+  this->dataPtr->max.Max(_b.dataPtr->max);
   return *this;
 }
 
