@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2014 Open Source Robotics Foundation
+ * Copyright (C) 2012 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,10 +31,11 @@ TEST(HelpersTest, Helpers)
   EXPECT_EQ(-12345, math::parseInt("-12345"));
   EXPECT_EQ(-12345, math::parseInt("    -12345"));
   EXPECT_EQ(0, math::parseInt("    "));
+  EXPECT_EQ(23, math::parseInt("23ab67"));
 
   EXPECT_EQ(math::NAN_I, math::parseInt(""));
   EXPECT_EQ(math::NAN_I, math::parseInt("?"));
-  EXPECT_EQ(math::NAN_I, math::parseInt("23ab67"));
+  EXPECT_EQ(math::NAN_I, math::parseInt("ab23ab67"));
 
   EXPECT_DOUBLE_EQ(12.345, math::parseFloat("12.345"));
   EXPECT_DOUBLE_EQ(-12.345, math::parseFloat("-12.345"));
@@ -54,10 +55,11 @@ TEST(HelpersTest, Helpers)
   EXPECT_TRUE(math::greaterOrNearEqual(1.0, 1.0 + 9e-3, 1e-2));
   EXPECT_FALSE(math::greaterOrNearEqual(1.0, 1.0 + 1.1e-2, 1e-2));
   EXPECT_DOUBLE_EQ(1.2345, math::parseFloat("1.2345e+0"));
+  EXPECT_DOUBLE_EQ(23.0, math::parseFloat("23ab67"));
 
   EXPECT_TRUE(math::isnan(math::parseFloat("")));
   EXPECT_TRUE(math::isnan(math::parseFloat("?")));
-  EXPECT_TRUE(math::isnan(math::parseFloat("23ab67")));
+  EXPECT_TRUE(math::isnan(math::parseFloat("ab23ab67")));
 
   EXPECT_EQ(1u, math::roundUpPowerOfTwo(0));
   EXPECT_EQ(1u, math::roundUpPowerOfTwo(1));
@@ -228,6 +230,89 @@ TEST(HelpersTest, Odd)
   EXPECT_FALSE(math::isOdd(ui));
 }
 
+/////////////////////////////////////////////////
+// Signum test
+TEST(HelpersTest, Signum)
+{
+  int i = 1;
+  signed s = 1;
+  signed int si = 1;
+  unsigned u = 1;
+  unsigned int ui = 1;
+  float f = 1.f;
+  double d = 1.;
+
+  EXPECT_EQ(1, math::signum(i));
+  EXPECT_EQ(1, math::signum(s));
+  EXPECT_EQ(1, math::signum(si));
+  EXPECT_EQ(1, math::signum(u));
+  EXPECT_EQ(1, math::signum(ui));
+  EXPECT_EQ(1, math::signum(f));
+  EXPECT_EQ(1, math::signum(d));
+
+  i = s = si = u = ui = 2;
+  f = 2.f;
+  d = 2.;
+
+  EXPECT_EQ(1, math::signum(i));
+  EXPECT_EQ(1, math::signum(s));
+  EXPECT_EQ(1, math::signum(si));
+  EXPECT_EQ(1, math::signum(u));
+  EXPECT_EQ(1, math::signum(ui));
+  EXPECT_EQ(1, math::signum(f));
+  EXPECT_EQ(1, math::signum(d));
+
+  i = s = si = u = ui = 0;
+  f = 0.f;
+  d = 0.;
+
+  EXPECT_EQ(0, math::signum(i));
+  EXPECT_EQ(0, math::signum(s));
+  EXPECT_EQ(0, math::signum(si));
+  EXPECT_EQ(0, math::signum(u));
+  EXPECT_EQ(0, math::signum(ui));
+  EXPECT_EQ(0, math::signum(f));
+  EXPECT_EQ(0, math::signum(d));
+
+  i = s = si = -1;
+  f = -1.f;
+  d = -1.;
+
+  EXPECT_EQ(-1, math::signum(i));
+  EXPECT_EQ(-1, math::signum(s));
+  EXPECT_EQ(-1, math::signum(si));
+  EXPECT_EQ(-1, math::signum(f));
+  EXPECT_EQ(-1, math::signum(d));
+
+  i = s = si = -2;
+  f = -2.f;
+  d = -2.;
+
+  EXPECT_EQ(-1, math::signum(i));
+  EXPECT_EQ(-1, math::signum(s));
+  EXPECT_EQ(-1, math::signum(si));
+  EXPECT_EQ(-1, math::signum(f));
+  EXPECT_EQ(-1, math::signum(d));
+
+  f = -2.5f;
+  d = -2.5;
+
+  EXPECT_EQ(-1, math::signum(f));
+  EXPECT_EQ(-1, math::signum(d));
+
+  f = 2.5f;
+  d = 2.5;
+
+  EXPECT_EQ(1, math::signum(f));
+  EXPECT_EQ(1, math::signum(d));
+
+  f = 1e-10f;
+  d = 1e-10;
+
+  EXPECT_EQ(1, math::signum(f));
+  EXPECT_EQ(1, math::signum(d));
+}
+
 /////////////////////////////////////////////////
 TEST(HelpersTest, Sort)
 {
@@ -330,7 +415,7 @@ TEST(HelpersTest, Volume)
 /////////////////////////////////////////////////
 TEST(HelpersTest, Pair)
 {
-#ifdef _MSC_VER
+#if defined _MSC_VER || defined __arm__
   math::PairInput maxA = math::MAX_UI16;
   math::PairInput maxB = math::MAX_UI16;
 #else
@@ -342,7 +427,7 @@ TEST(HelpersTest, Pair)
 
   // Maximum parameters should generate a maximum key
   math::PairOutput maxKey = math::Pair(maxA, maxB);
-#ifdef _MSC_VER
+#if defined _MSC_VER || defined __arm__
   EXPECT_EQ(maxKey, math::MAX_UI32);
 #else
   EXPECT_EQ(maxKey, math::MAX_UI64);
@@ -352,7 +437,7 @@ TEST(HelpersTest, Pair)
   EXPECT_EQ(maxC, maxA);
   EXPECT_EQ(maxD, maxB);
 
-#ifdef _MSC_VER
+#if defined _MSC_VER || defined __arm__
   math::PairInput minA = math::MIN_UI16;
   math::PairInput minB = math::MIN_UI16;
 #else
@@ -363,7 +448,7 @@ TEST(HelpersTest, Pair)
 
   // Minimum parameters should generate a minimum key
   math::PairOutput minKey = math::Pair(minA, minB);
-#ifdef _MSC_VER
+#if defined _MSC_VER || defined __arm__
   EXPECT_EQ(minKey, math::MIN_UI32);
 #else
   EXPECT_EQ(minKey, math::MIN_UI64);
@@ -378,13 +463,13 @@ TEST(HelpersTest, Pair)
 
   // Just a simple test case
   {
-    int a = 10;
-    int b = 20;
+    unsigned int a = 10;
+    unsigned int b = 20;
     math::PairInput c, d;
 
     auto key = math::Pair(static_cast<math::PairInput>(a),
                           static_cast<math::PairInput>(b));
-    EXPECT_EQ(key, 410);
+    EXPECT_EQ(key, 410u);
     EXPECT_TRUE(key != maxKey);
     EXPECT_TRUE(key != minKey);
 
@@ -414,7 +499,7 @@ TEST(HelpersTest, Pair)
       }
     }
 
-#ifndef _MSC_VER
+#if !defined _MSC_VER && !defined __arm__
     // Iterate over large numbers, and check for unique keys.
     for (math::PairInput a = math::MAX_UI32-5000; a < math::MAX_UI32; a++)
     {
