@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2014 Open Source Robotics Foundation
+ * Copyright (C) 2012 Open Source Robotics Foundation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -133,7 +133,10 @@ TEST(Vector4dTest, Vector4d)
   EXPECT_TRUE(v.IsFinite());
 
   // ::operator[]
-  v.Set(1, 2, 3, 4);
+  v[0] = 1;
+  v[1] = 2;
+  v[2] = 3;
+  v[3] = 4;
   EXPECT_DOUBLE_EQ(v[0], 1);
   EXPECT_DOUBLE_EQ(v[1], 2);
   EXPECT_DOUBLE_EQ(v[2], 3);
@@ -141,7 +144,7 @@ TEST(Vector4dTest, Vector4d)
 }
 
 /////////////////////////////////////////////////
-TEST(Vector4dTest, IndexException)
+TEST(Vector4dTest, NoException)
 {
   math::Vector4d v(1, 2, 3, 4);
   EXPECT_NO_THROW(math::equal(v[0], 1.0));
@@ -149,7 +152,8 @@ TEST(Vector4dTest, IndexException)
   EXPECT_NO_THROW(math::equal(v[2], 3.0));
   EXPECT_NO_THROW(math::equal(v[3], 4.0));
 
-  EXPECT_THROW(math::equal(v[4], 5.0), math::IndexException);
+  EXPECT_NO_THROW(math::equal(v[4], 5.0));
+  EXPECT_DOUBLE_EQ(v[4], 4.0);
 }
 
 /////////////////////////////////////////////////
